@@ -127,7 +127,8 @@ class TypingChecker(BaseChecker):
         "R6006": (
             "Type `%s` is used more than once in union type annotation. Remove redundant typehints.",
             "redundant-typehint-argument",
-            "Duplicated type arguments will be skipped by `mypy` tool, therefore should be removed to avoid confusion.",
+            "Duplicated type arguments will be skipped by `mypy` tool, therefore should be "
+            "removed to avoid confusion.",
         ),
     }
     options = (
