@@ -25,7 +25,7 @@ class _DeprecatedChecker(DeprecatedMixin, BaseChecker):
 
     def deprecated_arguments(
         self, method: str
-    ) -> (tuple[tuple[int | None, str], ...] | tuple[tuple[int, str], tuple[int, str]]):
+    ) -> tuple[tuple[int | None, str], ...] | tuple[tuple[int, str], tuple[int, str]]:
         if method == "myfunction1":
             # def myfunction1(arg1, deprecated_arg1='spam')
             return ((1, "deprecated_arg1"),)
@@ -53,6 +53,7 @@ class _DeprecatedChecker(DeprecatedMixin, BaseChecker):
         return {".deprecated_decorator"}
 
 
+# pylint: disable-next = too-many-public-methods
 class TestDeprecatedChecker(CheckerTestCase):
     CHECKER_CLASS = _DeprecatedChecker
 
@@ -129,7 +130,7 @@ class TestDeprecatedChecker(CheckerTestCase):
                 line=9,
                 col_offset=0,
                 end_line=9,
-                end_col_offset=21,
+                end_col_offset=12,
             )
         ):
             self.checker.visit_call(node)
@@ -485,7 +486,6 @@ class TestDeprecatedChecker(CheckerTestCase):
             self.checker.visit_call(node)
 
     def test_class_deprecated_arguments(self) -> None:
-
         node = astroid.extract_node(
             """
         class MyClass:
