@@ -164,7 +164,7 @@ def test_parse_format_method_string() -> None:
     ]
     for fmt, count in samples:
         keys, num_args, pos_args = utils.parse_format_method_string(fmt)
-        keyword_args = len({k for k, l in keys if not isinstance(k, int)})
+        keyword_args = len({k for k, _ in keys if not isinstance(k, int)})
         assert keyword_args + num_args + pos_args == count
 
 
@@ -414,6 +414,7 @@ def test_if_sys_guard() -> None:
     assert utils.is_sys_guard(code[2]) is False
 
 
+@pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_if_typing_guard() -> None:
     code = astroid.extract_node(
         """
@@ -447,6 +448,16 @@ def test_if_typing_guard() -> None:
     assert utils.is_typing_guard(code[3]) is False
 
 
+def test_in_type_checking_block() -> None:
+    code = astroid.extract_node(
+        """
+    if TYPE_CHECKING:  # don't import this!
+        import math  #@
+    """
+    )
+    assert utils.in_type_checking_block(code) is False
+
+
 def test_is_empty_literal() -> None:
     list_node = astroid.extract_node("a = []")
     assert utils.is_base_container(list_node.value)
@@ -484,12 +495,14 @@ def test_deprecation_check_messages() -> None:
             def visit_assname(self, node: nodes.NodeNG) -> None:
                 pass
 
-        assert len(records) == 1
-        assert (
-            records[0].message.args[0]
-            == "utils.check_messages will be removed in favour of calling utils.only_required_for_messages in pylint 3.0"
+        deprecationMessage = (
+            "utils.check_messages will be removed in "
+            "favour of calling utils.only_required_for_messages in pylint 3.0"
         )
 
+        assert len(records) == 1
+        assert records[0].message.args[0] == deprecationMessage
+
 
 def test_is_typing_member() -> None:
     code = astroid.extract_node(
