@@ -1,7 +1,7 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 # Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
-
+import os
 from pathlib import Path
 
 import pytest
@@ -13,7 +13,8 @@ from pylint.testutils.pyreverse import (
 )
 
 FUNCTIONAL_DIR = Path(__file__).parent / "functional"
-CLASS_DIAGRAM_TESTS = get_functional_test_files(FUNCTIONAL_DIR / "class_diagrams")
+CLASS_DIAGRAMS_DIR = FUNCTIONAL_DIR / "class_diagrams"
+CLASS_DIAGRAM_TESTS = get_functional_test_files(CLASS_DIAGRAMS_DIR)
 CLASS_DIAGRAM_TEST_IDS = [testfile.source.stem for testfile in CLASS_DIAGRAM_TESTS]
 
 
@@ -24,9 +25,23 @@ CLASS_DIAGRAM_TEST_IDS = [testfile.source.stem for testfile in CLASS_DIAGRAM_TES
 )
 def test_class_diagrams(testfile: FunctionalPyreverseTestfile, tmp_path: Path) -> None:
     input_file = testfile.source
+    input_path = os.path.dirname(input_file)
+    if testfile.options["source_roots"]:
+        source_roots = ",".join(
+            [
+                os.path.realpath(
+                    os.path.expanduser(os.path.join(input_path, source_root))
+                )
+                for source_root in testfile.options["source_roots"]
+            ]
+        )
+    else:
+        source_roots = ""
     for output_format in testfile.options["output_formats"]:
         with pytest.raises(SystemExit) as sys_exit:
             args = ["-o", f"{output_format}", "-d", str(tmp_path)]
+            if source_roots:
+                args += ["--source-roots", source_roots]
             args.extend(testfile.options["command_line_args"])
             args += [str(input_file)]
             Run(args)
